@@ -9,17 +9,17 @@ import pandas as pd
 import xarray as xr
 import yaml
 
-from src.mhw_detect.detection.detect import prepare_data
+from src.mhw_detect.detection.detect import prepare_computation
 from src.mhw_detect.detection.parser import (
     check_climato_period,
     check_file_exist,
     count_files,
     parse_data,
-    parse_param,
+    get_optional_datasets,
 )
 
 
-def check_extension(ctx, param, value):
+def check_extension(ctx, param, value: str):
     if not value.endswith((".parquet", ".csv")):
         raise click.BadParameter("The extension must be .parquet or .csv")
     else:
@@ -88,25 +88,28 @@ def extreme_events(
         click.echo(repr(error))
         sys.exit()
 
-    param = parse_param(conf)
+    param = conf["params"]
 
-    def output_path(file_name):
+    def output_path(file_name: str) -> str:
         return os.path.join(output, file_name)
 
-    def save_dataframe(dataframe):
+    def save_dataframe(dataframe: pd.DataFrame) -> None:
         if output_df.endswith(".parquet"):
             dataframe.to_parquet(output_path(output_df))
         else:
             dataframe.to_csv(output_path(output_df), sep=";")
 
     if geographical_subset is not None:
-        data = parse_data(conf, False)
+        datasets = parse_data(conf, False)
+        data = datasets["data"]
 
-        lat = geographical_subset[0:2]
-        lon = geographical_subset[2:4]
+        optional_datasets = get_optional_datasets(datasets)
 
-        prepare_data(
-            0, output, mask=mask, lat=lat, lon=lon, p=param["pctile"], **data, **param
+        if optional_datasets is None:
+            check_climato_period(conf)
+
+        prepare_computation(
+            0, param, data, output, mask, optional_datasets, lat_lon=geographical_subset
         )
 
         click.echo("Creating csv")
@@ -114,24 +117,29 @@ def extreme_events(
         save_dataframe(df)
 
         if categ_map:
+            click.echo("Creating mask")
             os.rename(output_path("0.txt.nc"), output_path(categ_map))
 
     else:
-        data = parse_data(conf)
         nfile = count_files(conf)
 
-        if "clim" not in data:
+        datasets = parse_data(conf)
+        data = datasets["data"]
+
+        optional_datasets = get_optional_datasets(datasets)
+
+        if optional_datasets is None:
             check_climato_period(conf)
 
         pool = mp.Pool()
         pool.imap(
             partial(
-                prepare_data,
+                prepare_computation,
+                detect_options=param,
+                data=data,
                 outdir=output,
                 mask=mask,
-                p=param["pctile"],
-                **data,
-                **param
+                optional_datasets=optional_datasets,
             ),
             range(1, nfile),
         )
@@ -142,7 +150,7 @@ def extreme_events(
 
         click.echo("Saving dataframe")
 
-        def f(i):
+        def f(i: str) -> pd.DataFrame:
             return pd.read_csv(i, sep=";")
 
         filepaths = [output_path(str(i) + ".txt") for i in range(1, nfile)]
