@@ -1,42 +1,39 @@
 import glob
 import os
+from typing import Union
 
 import xarray as xr
 
 
-def check_precalc_clim_thresh(data):
+def check_precalc_clim_thresh(data: dict[str, dict[str, str]]) -> None:
     if not {"clim", "percent"} <= data.keys():
         print(
-            "Precalculated mean and/or percentile have not been referenced in config file. \n\
+            "Precalculated climatological mean and/or percentile \
+            have not been referenced in config file. \n\
         They will be recalculated by Hobday's method."
         )
 
 
-def check_file_exist(conf):
+def check_file_exist(conf: dict[str, dict[str, dict[str, str]]]) -> None:
     for datas in conf["data"]:
         if not os.path.exists(conf["data"][datas]["path"]):
             raise ValueError("This file does not exist: ", conf["data"][datas]["path"])
 
 
-def parse_data(conf, cut=True):
+def parse_data(
+    conf: dict[str, dict[str, dict[str, str]]], cut: bool = True
+) -> dict[str, dict[str, str]]:
+    data = conf["data"]
+
     if cut:
-        parse_path = lambda p: os.path.join(os.path.dirname(p), "Cut_")
-    else:
-        parse_path = lambda p: p
+        for key in data.keys():
+            data[key]["path"] = os.path.join(os.path.dirname(data[key]["path"]), "Cut_")
 
-    data = {
-        datas: [parse_path(conf["data"][datas]["path"]), conf["data"][datas]["var"]]
-        for datas in conf["data"]
-    }
     check_precalc_clim_thresh(data)
     return data
 
 
-def parse_param(conf):
-    return {params: conf["params"][params] for params in conf["params"]}
-
-
-def count_files(conf):
+def count_files(conf: dict[str, dict[str, dict[str, str]]]) -> int:
     return (
         len(
             [
@@ -50,13 +47,25 @@ def count_files(conf):
     )
 
 
-def check_climato_period(conf):
+def get_optional_datasets(
+    datasets: dict[str, dict[str, str]]
+) -> Union[None, dict[str, dict[str, str]]]:
+    if not {"clim", "percent"} <= datasets.keys():
+        optional_datasets = None
+    else:
+        optional_datasets = datasets
+        del optional_datasets["data"]
+
+    return optional_datasets
+
+
+def check_climato_period(conf: dict[str, dict[str, dict[str, str]]]) -> None:
     ds = xr.open_dataset(conf["data"]["data"]["path"])
     period = conf["params"]["climatologyPeriod"]
 
     min = ds.time.min().values.astype("datetime64[Y]").astype(int) + 1970
     max = ds.time.max().values.astype("datetime64[Y]").astype(int) + 1970
 
-    assert (period[0] >= min) or (
+    assert (period[0] >= min) and (
         period[1] <= max
     ), "The dataset does not cover the climatologyPeriod."
